@@ -33,7 +33,7 @@ class BasicMultiArgumentAuthentication(authentication.BasicAuthentication):
                 credentials[key] = val
 
         # authenticate the user via Django's auth backends
-        user = authenticate(**credentials)
+        user = authenticate(request=request, **credentials)
 
         if user is None:
             raise exceptions.AuthenticationFailed("Invalid credentials.")
