@@ -91,11 +91,9 @@ def validate_and_create_buffer_data(  # noqa: C901
         )
         if expected_model_uuid != record["model_uuid"]:
             raise ValidationError(
-                {
-                    "model_uuid": "Does not match results of calling {}.compute_namespaced_id".format(
-                        Model.__class__.__name__
-                    )
-                }
+                "Does not match results of calling {}.compute_namespaced_id".format(
+                    Model.__class__.__name__
+                )
             )
 
         # ensure the profile is marked onto the buffer record
@@ -104,30 +102,24 @@ def validate_and_create_buffer_data(  # noqa: C901
         # ensure the partition is within the transfer session's filter
         if not transfer_session.get_filter().contains_partition(record["partition"]):
             raise ValidationError(
-                {
-                    "partition": "Partition {} is not contained within filter for TransferSession ({})".format(
-                        record["partition"], transfer_session.filter
-                    )
-                }
+                "Partition {} is not contained within filter for TransferSession ({})".format(
+                    record["partition"], transfer_session.filter
+                )
             )
 
         # ensure that all nested RMCB models are properly associated with this record and transfer session
         for rmcb in record.pop("rmcb_list"):
             if rmcb["transfer_session"] != transfer_session.id:
                 raise ValidationError(
-                    {
-                        "rmcb_list": "Transfer session on RMCB ({}) does not match Buffer's TransferSession ({})".format(
-                            rmcb["transfer_session"], transfer_session
-                        )
-                    }
+                    "Transfer session on RMCB ({}) does not match Buffer's TransferSession ({})".format(
+                        rmcb["transfer_session"], transfer_session
+                    )
                 )
             if rmcb["model_uuid"] != record["model_uuid"]:
                 raise ValidationError(
-                    {
-                        "rmcb_list": "Model UUID on RMCB ({}) does not match Buffer's Model UUID ({})".format(
-                            rmcb["model_uuid"], record["model_uuid"]
-                        )
-                    }
+                    "Model UUID on RMCB ({}) does not match Buffer's Model UUID ({})".format(
+                        rmcb["model_uuid"], record["model_uuid"]
+                    )
                 )
             rmcb["transfer_session_id"] = rmcb.pop("transfer_session")
             rmcb_list += [RecordMaxCounterBuffer(**rmcb)]
@@ -238,3 +230,21 @@ class SyncSignalGroup(SyncSignal):
         Fires the `completed` signal.
         """
         self.completed.fire()
+
+
+def lock_partitions(backend, sync_filter=None, shared=False):
+    """
+    Lock all partitions for a filter, and really lock everything if the filter is null
+
+    :type backend: morango.sync.backends.base.BaseSQLWrapper
+    :type sync_filter: morango.models.certificates.Filter|None
+    :type shared: bool
+    """
+    if sync_filter is None:
+        backend._lock_all_partitions(shared=shared)
+    else:
+        # parse the first 32 chars to obtain the primary partitions in the filter
+        partitions = set(f[:32] for f in sync_filter)
+        # for every unique partition, acquire a lock
+        for partition in partitions:
+            backend._lock_partition(partition, shared=shared)
